@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the hdl_registers project, a HDL register generator fast enough to be run
+# This file is part of the hdl_registers project, a HDL register generator fast enough to run
 # in real time.
 # https://hdl-registers.com
 # https://gitlab.com/hdl_registers/hdl_registers
@@ -55,7 +55,7 @@ THIS_DIR = Path(__file__).parent
 class {self._class_name}:
 
     """
-    Instantiate this class to get the RegisterList object for the {self.module_name} module.
+    Instantiate this class to get the RegisterList object for the '{self.module_name}' module.
     """
 
     def __new__(cls):
@@ -68,7 +68,7 @@ class {self._class_name}:
 
 def get_register_list():
     """
-    Return a RegisterList object with the registers/constants from the {self.module_name} module.
+    Return a RegisterList object with the registers/constants from the '{self.module_name}' module.
     Recreated from a python pickle file.
     """
     return {self._class_name}()
